vortex86ex: Defer checking PS/2 keyboard controller system flag

Don't check keyboard controller system flag until before calling
pc_keyboard_init(). This makes waiting time shorter.

Change-Id: I2cdb533a5b25575e1717434533a60decf748f6d8
Signed-off-by: Andrew Wu <arw@dmp.com.tw>
Reviewed-on: http://review.coreboot.org/3958
Tested-by: build bot (Jenkins)
Reviewed-by: Ronald G. Minnich <rminnich@gmail.com>
diff --git a/src/southbridge/dmp/vortex86ex/southbridge.c b/src/southbridge/dmp/vortex86ex/southbridge.c
index d8914c0..ddb99b8 100644
--- a/src/southbridge/dmp/vortex86ex/southbridge.c
+++ b/src/southbridge/dmp/vortex86ex/southbridge.c
@@ -138,7 +138,13 @@
 
 	// disable firmware uploading.
 	pci_write_config32(dev, SB_REG_IPFCR, reg_sb_c0 & ~0x400L);
-	// wait keyboard controller ready by checking status port bit 2.
+}
+
+static void kbc_wait_system_flag(void)
+{
+	/* wait keyboard controller ready by checking system flag
+	 * (status port bit 2).
+	 */
 	post_code(POST_KBD_CHK_READY);
 	while ((inb(0x64) & 0x4) == 0) {
 	}
@@ -571,6 +577,7 @@
 
 	fix_cmos_rtc_time();
 	rtc_init(0);
+	kbc_wait_system_flag();
 	pc_keyboard_init(0);
 }